@@ -1,6 +1,6 @@
 #
 # GaussSum (http://gausssum.sf.net)
-# Copyright (C) 2006-2012 Noel O'Boyle <baoilleach@gmail.com>
+# Copyright (C) 2006-2013 Noel O'Boyle <baoilleach@gmail.com>
 #
 # This program is free software; you can redistribute and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -16,14 +16,14 @@ import os
 import math
 import gausssum.utils
 
-from plot import DisplayPlot
-from gnupy import Gnuplot
-from folder import folder
+from .plot import DisplayPlot
+from .mpl import MPLPlot
+from .folder import folder
 
 def activity_to_intensity(activity, frequency, excitation, temperature):
     """Convert Raman acitivity to Raman intensity according to
     Krishnakumar et al, J. Mol. Struct., 2004, 702, 9."""
-    
+
     excitecm = 1 / (1e-7 * excitation)
     f = 1e-13
     above = f * (excitecm - frequency)**4 * activity
@@ -51,7 +51,7 @@ def get_scaling_factors(filename, scale):
     inputfile.close()
     return scale
 
-def Vibfreq(root,screen,logfile,logfilename,start,end,numpts,FWHM,typeofscale,scalefactor,excitation,temperature,gnuplotexec):
+def Vibfreq(root,screen,logfile,logfilename,start,end,numpts,FWHM,typeofscale,scalefactor,excitation,temperature):
 
     def dofreqs(name,act):
 
@@ -80,19 +80,19 @@ def Vibfreq(root,screen,logfile,logfilename,start,end,numpts,FWHM,typeofscale,sc
                 screen.write("found\n")
                 general = False
                 get_scaling_factors(inputfilename, scale) # Update scaling factors in 'scale' from file
-           
+
         for i in range(len(freq)): # Scale the freqs
             freq[i] = freq[i]*scale[i]
-        
+
         # Convolute the spectrum
         spectrum = gausssum.utils.Spectrum(start,end,numpts,
-                                           [zip(freq,act)],
+                                           [list(zip(freq,act))],
                                            FWHM,gausssum.utils.lorentzian)
         if name == "Raman":
             intensity = [activity_to_intensity(activity, frequency, excitation, temperature)
                          for activity, frequency in zip(act, freq)]
             spectrum_intensity = gausssum.utils.Spectrum(start,end,numpts,
-                                           [zip(freq, intensity)],
+                                           [list(zip(freq, intensity))],
                                            FWHM,gausssum.utils.lorentzian)
 
         outputfile = open(os.path.join(gaussdir,filename),"w")
@@ -118,35 +118,33 @@ def Vibfreq(root,screen,logfile,logfilename,start,end,numpts,FWHM,typeofscale,sc
 
         if root:
 
-            # Draw using Gnuplot
-            screen.write("Plotting with Gnuplot\n")
             if general==True:
                 title = "%s spectrum scaled by %f" % (name, scalefactor)
             else:
                 title = "%s spectrum scaled by individual scaling factors" % name
 
             if name == "IR":
-                g = Gnuplot(gnuplotexec)
-                g.commands("set xlabel 'Frequency (cm-1)'",
-                           "set ylabel 'IR activity'",
-                           "set yrange [*:*] reverse",
-                           "set xrange [*:*] reverse",
-                           "set key bottom")
-                g.data(zip(spectrum.xvalues,spectrum.spectrum[:,0]),"title '%s' with lines" % title)
-                DisplayPlot(root,g,"%s Spectrum" % name)
+                g = MPLPlot()
+                g.setlabels("Frequency (cm$^{-1}$)", "IR activity")
+                g.subplot.invert_xaxis()
+                g.subplot.invert_yaxis()
+
+                g.data(zip(spectrum.xvalues,spectrum.spectrum[:,0]), title=title, lines=True)
+                g.subplot.legend(loc="lower right", prop={'size':8})
+                DisplayPlot(root, g, "%s Spectrum" % name)
 
             if name == "Raman":
                 for type, spec in [("activity", spectrum),
                                    ("intensity", spectrum_intensity)]:
-                    g = Gnuplot(gnuplotexec)
-                    g.commands("set xlabel 'Frequency (cm-1)'",
-                               "set ylabel 'Raman %s'" % type)
-                    g.data(zip(spec.xvalues,spec.spectrum[:,0]),"title '%s' with lines" % title)
-                    DisplayPlot(root,g,"%s Spectrum" % name)
-        
+                    g = MPLPlot()
+                    g.setlabels("Frequency (cm$^{-1}$)", "Raman %s" % type)
+                    g.data(zip(spec.xvalues,spec.spectrum[:,0]), lines=True, title=title)
+                    g.subplot.legend(loc="upper right", prop={'size':8})
+                    DisplayPlot(root, g, "%s Spectrum" % name)
+
 
     ############## START OF MAIN FUNCTION #############
-        
+
     screen.write("Starting to analyse the vibrational frequencies\n")
 
     # Create a new output folder if necessary (returns the location of it in any case)
@@ -159,7 +157,7 @@ def Vibfreq(root,screen,logfile,logfilename,start,end,numpts,FWHM,typeofscale,sc
         dofreqs("Raman",logfile.vibramans)
 
     screen.write("Finished\n")
-    
+
     return True
-        
+
     ############## END OF MAIN FUNCTION #############
